Get a set of concept set targets and candidate concepts for evaluating the process of concept adjudication (determining) whether a concept belongs to a concept set.

Use the evaluateConceptAdjudication() function to evaluate your adjudications of these concepts.

getConceptsForAdjudication()

Value

A data frame with the following columns:

  • targetName: The name of the target for the concept set (what the concept set should be about).

  • targetDefinition: A detailed description of the concept set target.

  • conceptId: The concept ID of the candidate concept.

  • conceptName: The name of the candidate concept.

  • vocabularyId: The vocabulary ID of the candidate concept.

  • domainId: The domain ID of the candidate concept.

  • conceptClassId: The concept class ID of the candidate concept.