Concept sets as created by AI3 in the MindsMeetMachines challenge. The dataset includes the set of concept IDs included in each of the six concept sets according to AI3.
data(ai3ConceptSets)a dataframe with 681 rows and 2 variables
id : The ID of the concept set
conceptId: The concept ID of a concept included in the concept set